16.71. cdist-type__install_mkfs(7) — cdist 6.9.4 documentation

# 16.71. cdist-type__install_mkfs(7)

## 16.71.1. NAME

cdist-type__install_mkfs - build a linux file system

## 16.71.2. DESCRIPTION

This cdist type is a wrapper for the mkfs command.

## 16.71.3. REQUIRED PARAMETERS

type

  The filesystem type to use. Same as used with mkfs -t.

## 16.71.4. OPTIONAL PARAMETERS

device

  defaults to object_id

options

  file system-specific options to be passed to the mkfs command

blocks

  the number of blocks to be used for the file system

## 16.71.5. EXAMPLES

    # reiserfs /dev/sda5
    __install_mkfs /dev/sda5 --type reiserfs

    # same thing with explicit device
    __install_mkfs whatever --device /dev/sda5 --type reiserfs

    # jfs with journal on /dev/sda2
    __install_mkfs /dev/sda1 --type jfs --options "-j /dev/sda2"

## 16.71.6. SEE ALSO

mkfs(8)

## 16.71.7. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.71.8. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.